%% Skript zur grafischen Ausgabe von Klimadiagrammen
% nach den Richtlinien von Heinrich Walter und Helmut Lieth
%
% Dezember 2011 von Dominik Zobel
%
%
% Aufbau
%
% 1.) Defintion der Klimadatenvektoren: Bereitstellung der drei relevanten Vektoren
%
% 2.) Kontrollpult: Anpassungsmöglichkeiten der grafischen Ausgabe
%
%  ---- Ab hier sollten keine Änderungen mehr nötig sein ----
%
% 3.) Berechnungen
%
% 4.) Grafische Ausgabe



%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%       A B S C H N I T T    ( 1 )       %%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% ---      Bereitstellung der drei relevanten Vektoren der Klimadaten      --- %%
%                                                                                %


clear all
close all


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% -- Sammlung verschiedener Klimadaten -- %%

% Das Skript erwartet drei Vektoren, "place", "mm" und "tmp", die hier definiert werden
% - "mm" ist eine 1x12 Matrix mit den Niederschlagswerten der 12 Monate, beginnend mit Januar
% - "tmp" enthält die Temperaturmittelwerte der 12 Monate, wieder von Januar bis Dezember
% - "place" ist ein 4x1 Zellenvektor.
%      -- Die erste Zelle enthält den Namen der Stadt/Standort, an dem die Werte gemessen worden sind
%      -- Die zweite und dritte Zelle enthalten die geographische Lage, zuerst Breitengrad,
%           dann Längengrad. Dabei sind das Gradzeichen durch \circ und das Minutenzeichen durch
%           \prime zu ersetzen (ohne Leerzeichen). Außerdem ist eine N/S bzw E/W Angabe beizufügen.
%      -- Der letzte Eintrag ist die Höhe der Stadt/Messgeräts über NN

%place={'Dublin';'53\circ26\primeN';'6\circ15\primeW';'68m'};
%mm=[71 52 51 43 62 55 66 80 77 68 67 77];
%tmp=[4.5 4.8 6.5 8.4 10.5 13.5 15 14.8 13.1 10.5 7.2 5.8];
% Quelle: wikipedia.de / GeoKlima 2.1 / Handbuch ausgewählter Klimastationen der Erde, Manfred J. Müller, Trier 1996

place={'Hamburg';'53\circ38\primeN';'9\circ59\primeE';'11m'};
mm=[61.2 41.3 56.4 51 57.3 74.4 81.9 70 70.2 63.1 71.1 72.3];
tmp=[0.5 1.1 3.7 7.3 12.2 15.5 16.8 16.6 13.5 9.7 5.1 1.9];
% Quelle: wikipedia.de / GeoKlima 2.1 / Handbuch ausgewählter Klimastationen der Erde, Manfred J. Müller, Trier 1996

%place={'Minsk';'53\circ55\primeN';'27\circ33\primeE';'280m'};
%mm=[40 34 42 42 62 83 88 72 60 49 52 53];
%tmp=[-7 -5.7 -1.2 6.4 13 16.2 17.5 16.7 12.2 6.6 0.9 -3.9];
% Quelle: http://worldweather.wmo.int/ - Temperatur gemittelt

%place={'Irkutsk';'52\circ17\primeN';'104\circ16\primeE';'444m'};
%mm=[12 9 13 19 33 62 120 86 50 30 18 19];
%tmp=[-18.3 -16 -7 2.1 9.9 15.5 18.1 15.8 9.6 1.7 -8.2 -15.6];
% Quelle: http://worldweather.wmo.int/ - Temperatur gemittelt

%place={'Petropawlowsk-Kamtschatski';'53\circ1\primeN';'158\circ39\primeE';'150m'};
%mm=[81 70 62 54 66 63 80 97 102 139 95 86];
%tmp=[-8.5 -8 -5.5 -1.3 3.1 7.7 11.2 12.4 9.5 4.4 -2.3 -6.2];
% Quelle: http://worldweather.wmo.int/ - Temperatur gemittelt

%place={'Unalaska';'53\circ54\primeN';'166\circ32\primeW';'4m'};
%mm=[184.9 161.3 137.2 87.9 101.1 63 55.6 68.3 132.3 182.1 171.7 200.4];
%tmp=[0.3 0.3 0.8 2.3 5.2 8.2 10.8 11.8 9.3 5.7 2 1.5];
% Quelle: http://www.wrcc.dri.edu/ - in Grad Celsius/mm umgerechnet und gemittelt

%place={'Edmonton';'53\circ34\primeN';'113\circ31\primeW';'671m'};
%mm=[22.5 14.6 16.6 26 49 87.1 91.7 69 43.7 17.9 17.9 20.9];
%tmp=[-11.7 -8.4 -2.6 5.5 11.7 15.5 17.5 16.6 11.3 5.6 -4.1 -9.6];
% Quelle: http://www.climate.weatheroffice.gc.ca

% --- Mehr ---%

%place={'Death Valley';'36\circ18\primeN';'116\circ26\primeW';'-51m'};
%mm=[6 6 4 3 2 1 0 0 0 2 0 1];
%tmp=[11.4 15.7 19.9 25.2 29.4 35.1 39.0 37.7 33.4 25.8 16.9 11.7];
% Quelle: wikipedia.de / GeoKlima 2.1 / Handbuch ausgewählter Klimastationen der Erde, Manfred J. Müller, Trier 1996

%place={'Cimbaj';'42\circ57\primeN';'59\circ49\primeE';'66m'};
%mm=[16 12 21 23 15 4 4 3 3 13 12 17];
%tmp=[-5.6 -4.5 2.9 12.9 25.5 25.2 27.3 24.5 18.1 9.8 3.5 -2.3];
% Quelle: wikipedia.de / GeoKlima 2.1 / Handbuch ausgewählter Klimastationen der Erde, Manfred J. Müller, Trier 1996

%place={'Manaus';'3\circ8\primeS';'60\circ1\primeW';'92m'};
%mm=[260.1 288.3 313.5 300.1 256.3 113.6 87.5 57.9 83.3 125.7 183 216.9];
%tmp=[26.8 26.8 26.9 27 27.1 27 27 27.8 28.2 28.3 27.9 27.4];
% Quelle: http://worldweather.wmo.int/ - Temperatur gemittelt

%place={'Cherrapunji';'25\circ15\primeN';'91\circ44\primeE';'1313m'};
%mm=[18 53 185 665 1280 2695 2446 1781 1100 493 69 13];
%tmp=[11.7 13.1 16.7 18.3 19.2 20.0 20.3 20.6 20.6 19.2 15.9 12.8];
% Quelle: wikipedia.de / GeoKlima 2.1 / Handbuch ausgewählter Klimastationen der Erde, Manfred J. Müller, Trier 1996

%place={'Werchojansk';'67\circ33\primeN';'133\circ23\primeE';'137m'};
%mm=[7 5 5 4 5 25 33 30 13 11 10 7];
%tmp=[-48.9 -43.7 -29.9 -13.0 2.0 12.2 15.3 11.0 2.6 -14.1 -36.1 -45.6];
% Quelle: wikipedia.de / GeoKlima 2.1 / Handbuch ausgewählter Klimastationen der Erde, Manfred J. Müller, Trier 1996



%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%       A B S C H N I T T    ( 2 )       %%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% ------   Anpassung und Kontrolle der Parameter zur grafischen Ausgabe   ------ %%
%                                                                                  %


%custom_plot_height=[-20 200];      % Manuelles Anpassen der Plothöhe. Ist der Vektor "custom_plot_height" ein leerer Vektor (oder auskommentiert),
                                    % dann werden die Ober- und Untergrenze des Plots automatisch bestimmt. Andernfalls werden zwei Werte erwartet:
                                    % - Die untere Grenze als Temperaturangabe (... , -40, -30, ... ,0) und
                                    % - die obere Grenze als Niederschlagsmaximalwert (... , 80, 100, 200, ...)
                                    % Falls ein Zwischenwert oder Dezimalwert angegeben wird, wird der automatisch der nächstentferntere Wert benutzt.

change_precipitation_scale=1;       % Üblicherweise wird die Niederschlagsskala über 100mm gestaucht. Dazu ist "change_precipitation_scale" auf (1)
                                    % zu setzen (empfohlen). Falls diese Stauchung aber nicht erwünscht ist, so kann sie durch (0) vermieden werden.
                                    % Bei extrem regenreichen Wetterdaten ist  mit "change_precipitation_scale" (2) auch eine doppelte Stauchung möglich.

      sharp100_change=0;            % Durch die Stauchung ab 100mm tritt eigentlich auch ein Knick auf. Da dieser Knick meistens nicht erwünscht ist, empfiehlt
                                    % es sich "sharp100_change" auf (0) zu setzen. Andernfalls (1). Hat nur einen Einfluss, wenn "change_precipitation_scale" nicht
                                    % Null ist

half_year_shift=0;                  % Für die Betrachtung wird meistens der Zeitraum Januar--Dezember auf der Nordhalbkugel verwendet (0). Um die
                                    % Jahreszeitenverschiebung auf der Südhalbkugel anzupassen (oder umgekehrt) kann der Betrachtungszeitraum um ein
                                    % halbes Jahr auf Juli--Juni verschoben werden. Dazu muss "half_year_shift" auf (1) gesetzt werden.

fsize=20;                           % Ändern der Schriftgröße für die Achsenbeschriftung. Die Titelschrift wird dadurch nicht beeinflusst.

line_width=2;                       % Dicke der Linien im Plot. Dabei haben die Temperaturkurve, die Niederschlagskurve und die blauen Balken alle die
                                    % hier definierte Dicke (für unterschiedliche Dicken zwischen den dreien muss eine Anpassung weiter unten stattfinden)
                                    % Die flächig wirkenden ariden Bereiche (Temperaturkurve über Niederschlagskurve) und die gestauchten Niederschlagsbereiche
                                    % über 100mm haben die doppelte Dicke "line_width"*2. Empfohlener Wert für "line_width": (2)

bar_density=8;                      % Anzahl an (blauen) Balken in einer Einheitslänge im Plot. Empfohlener Wert für "bar_density": (8)



%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%       A B S C H N I T T    ( 3 )       %%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% ------   Überprüfung der Eingabewerte und Berechnung der Endwerte   ------ %%
%                                                                              %


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% -- Überprüfung der zu verwendenden Vektoren -- %%

% Existieren die drei Hauptvariablen?
if ((~exist('place','var')) || (~exist('mm','var')) || (~exist('tmp','var')))
   disp(['Mindestens einer der drei benötigten Eingabevektoren existiert nicht']);
   return;
end

% Haben Sie die richtige Dimension?
if ((size(mm) ~= [1 12]) || (size(tmp) ~= [1 12]))
   disp(['Vektoren für Niederschlag/Temperatur müssen Vektoren der Dimension [1 12] sein']);
   return;
end

if (size(place) ~= [4 1])
   disp(['Vektor für Name, geographische Länge und Höhe muss Dimension [4 1] haben']);
   return;
end

% Stimmen die Werte auf dem ersten Blick?
if (max(tmp) > 50 )
   disp(['Temperatur muss kleiner 50 Grad sein']);
   return;
end

if (min(mm) < 0)
   disp(['Niederschlag muss größer Null sein']);
   return;
end

% Falls die Variable "custom_plot_height" der Einfachheit halber oben auskommentiert wurde, erzeuge Sie hier
if (~exist('custom_plot_height','var'))
   custom_plot_height=[];
end

% Wurde "custom_plot_height" oben definiert, besteht immernoch die Möglichkeit einer Fehleingabe...
if (size(custom_plot_height) ~= [1 2]) && (max(size(custom_plot_height)) ~= 0)
   disp(['Ungültige Angaben - Plothöhe wird automatisch festgelegt']);
   custom_plot_height=[];
end

if (size(custom_plot_height) == [1 2])
   if (custom_plot_height(1) >= custom_plot_height(2))
      disp(['Die obere Grenze der Plothöhe muss größer sein als die Untere - verwerfe manuelle Grenzen']);
      custom_plot_height=[];
   end
end

% Wenn der Plot gestaucht werden soll (was hauptsächlich grafisch geschieht, siehe weiter unten),
% dann sollen die Benutzereingaben entsprechend der in diesem Skript gewählten Art der Skalierung angepasst werden
if ((change_precipitation_scale ~= 0) && (size(custom_plot_height) == [1 2]))
   if (change_precipitation_scale == 2)
      custom_plot_height=[custom_plot_height(1) custom_plot_height(2)*0.1+90];
   else
      if (change_precipitation_scale ~= 1)
         disp(['Stauchungswert nicht implementiert - nehme Standardwert']);
      end
      custom_plot_height=[custom_plot_height(1) custom_plot_height(2)*0.2+80];
   end
end


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% -- Berechnung der Monatsverschiebung -- %%

if (half_year_shift == 1)
   % Schiebe die ersten sechs Monate hinten ran
   mm=[mm(7:12) mm(1:6)];
   tmp=[tmp(7:12) tmp(1:6)];
end


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% -- Stauchung der Skala für Niederschlagswerte größer als 100mm -- %%

xaxis=[0.5 1:1:12 12.5];            % Initialisierung der X-Achse (nur mit Vorsicht ändern)

scale_changing_points=[];           % Leere Matrix, in die die Einträge geschrieben werden, bei denen sich Übergänge über 100mm befinden

% Falls die Skala verändert werden soll, ist eine Behandlung der Fälle größer 100mm erforderlich (soweit vorhanden)
if (change_precipitation_scale ~= 0)

   % Treten Niederschlagswerte über 100mm auf? "precipitation_test" hat den Wert 0 an allen Stellen mit einem Niederschlag
   % zwischen Null und 99mm und den Wert 1 an allen Stellen mit einem Niederschlag zwischen 100 und 9999mm
   precipitation_test=ceil(floor(mm/100)/100);

   if ((max(precipitation_test) >= 1) && (sharp100_change ~= 0))
      % Bestimme die Schnittpunkte, bei denen ein Abknicken stattfindet

      % Erweitere zu 12+1 Werten um auch über die Veränderung vor Anfang/nach Ende eine Aussage treffen zu können
      ext_precipitation=[precipitation_test precipitation_test(1)];

      for i_check_precipitation=1:max(size(mm)) % 12

         % Wenn genau eine Null und eine Eins auftaucht (Stelle mit weniger und mit mehr als 100mm), dann soll der Punkt
         % berechnet werden, an dem die 100mm geschnitten werden
         if (ext_precipitation(i_check_precipitation)+ext_precipitation(i_check_precipitation+1) == 1)
            temp_value=i_check_precipitation+(100-mm(i_check_precipitation))/(mm(i_check_precipitation+1)-mm(i_check_precipitation));

            % Falls der Punkt nach der Dezembermitte (12.5) liegt, soll er auch entsprechend vor Januar (0.5 -- 1) eingetragen werden
            if (temp_value > xaxis(max(size(xaxis))))
               temp_value=temp_value-(xaxis(max(size(xaxis)))-xaxis(1));
            end

            scale_changing_points=[scale_changing_points;temp_value 100];
         end
      end
   end

   % Skaliere die Niederschlagswerte über 100mm ohne die anderen zu beeinflussen (precipitation_test hat nur Werte von 0, also unter
   % 100mm, und 1, also über 100mm, was hier ausgenutzt werden soll). Die Skalierung hat den Zweck, dass beim Plotten später lediglich
   % die Achsenbeschriftung über 100mm geändert werden soll.

   if (change_precipitation_scale == 1)
      % Im ersten Stauchungsfall hat also 150mm den Wert 110mm, 200mm wird zu 120mm, 350mm zu 150mm, usw.
      mm=mm+precipitation_test.*(0.8*(100-mm));
   else
      % Da hier nurnoch "change_precipitation_scale" (2) sein kann, wird keine weitere Abfrage durchgeführt.
      % Gestaucht wird hier wie folgt: 150mm wird zu 105mm, 200mm zu 110mm, 350mm zu 125mm, usw.
      mm=mm+precipitation_test.*(0.9*(100-mm));
   end

   % Aufräumen
   clear precipitation_test ext_precipitation i_check_precipitation temp_value
   % Übrig bleibt "scale_changing_points"
end


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% -- Bestimmung von Plothöhe und Grenzwerten -- %%

% Zuerst wird aus den vorhandenen Daten sinnvolle Grenzen ermittelt, unabhängig davon,
% ob die Grenze manuell gesetzt werden soll
tmp_top=max(ceil(tmp/10)*10)+10;
mm_top=max(ceil(mm/20)*20)+20;
tmp_bottom=min([floor(min(tmp/10))*20 0])-20;
mm_bottom=0;

% Soll die Plothöhe selbst festgelegt werden?
if (size(custom_plot_height) == [1 2])

   % Die Eingabe für "ylim_bottom" ist die Temperatur aus "custom_plot_height(1)"
   % Sie wird auf den nächstkleineren 10er Wert abgerundet und anschließend durch Multiplikation mit 2*10 als
   % negativer Niederschlagswert betrachtet, so dass beide Grenzen für den Niederschlag gültig sind
   ylim_bottom=floor(custom_plot_height(1)/10)*20;
   ylim_top=ceil(custom_plot_height(2)/20)*20;

   % Ein paar Warnhinweise ausspucken, wenn die Grenzen zu eng gewählt sind
   if (ylim_bottom > min(tmp_bottom,mm_bottom))
      disp(['Die gewählte untere Grenze ist niedriger als empfohlen']);
   end

   if (ylim_top < max(tmp_top,mm_top))
      disp(['Die gewählte obere Grenze ist niedriger als empfohlen']);
   end
else

   % In der automatischen Betrachtung soll nicht nur zum nächsten 20er Wert auf- bzw. abgerundet werden, sondern auch ein
   % zusätzlicher Abstand hinzuaddiert werden
   ylim_bottom=tmp_bottom;
   ylim_top=max([ceil(mm/20)*20 ceil(tmp/10)*20])+20;
end

xlim=[xaxis(1) xaxis(max(size(xaxis)))];
ylim=[ylim_bottom ylim_top];

% Aufräumen ("tmp_top" wird noch gebraucht)
clear ylim_bottom ylim_top mm_top tmp_bottom mm_bottom


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% -- Anpassen und Zusammenfassen der Daten -- %%

% Für den Niederschlag können Extrapunkte hinzugekommen sein, wenn "change_precipitation_scale" ungleich Null ist. In diesem Fall
% sind die Werte hinzuzufügen und nach ihrer Stelle an der x-Achse zu sortieren. Falls keine Änderungen betrachtet werden sollen,
% ist "scale_changing_points" noch immer eine leere Matrix und es entstehen keine Änderungen durch den folgenden Befehl
combined_mm=sortrows([[xaxis;(mm(1)+mm(12))/2 mm (mm(1)+mm(12))/2] scale_changing_points']')';

% Für die Temperaturen ist nichts weiter zu tun, als sie zusammenzufassen:
combined_tmp=[xaxis;(tmp(1)+tmp(12))/2 tmp (tmp(1)+tmp(12))/2];

% Jetzt stehen in der ersten Zeile alle (sortierten) X-Werte und in der zweiten Zeile die dazugehörigen Y-Werte
% Aufräumen
clear scale_changing_points


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%       A B S C H N I T T    ( 4 )       %%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% ------       Grafische Ausgabe der angepassten Klimadatenvektoren       ------ %%
%                                                                                  %

% Erstellen eines Plotfensters mit eigenem Namen und eigenen Längenangaben
fig_handle=figure('Name',['Klimadiagramm ',place{1}],'NumberTitle','off');
set(fig_handle,'Position',[680 560 560 560]) % Höhe vorher: 420

% Formatiere den Titel aus dem Zellenvektor "place"
tit_handle=title({['\fontsize{26}{\bf',place{1},'}'];['\fontsize{18}',place{2},'   ',place{3}];[place{4}]},'FontName','Helvetica','HorizontalAlignment','center');

% Alles soll in das gleiche Fenster geplottet werden
hold on


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% -- Manuelles Zeichnen von X- und Y-Grid -- %%

% Da aufgrund der später durchgeführten Farbänderung an den Achsen auch das Hintergrundgitter farbig wäre,
% soll das Gitter zuerst (als unterste Ebene) und in schwarz zu den gewählten Abständen gezeichnet werden
for i_plot_all_xgrid=xaxis(1):xaxis(max(size(xaxis)))
   plot([i_plot_all_xgrid i_plot_all_xgrid],[0.5*ylim(1) 0.5*ylim(2)],'k:')
end
for i_plot_all_ygrid=0:(ylim(2)-ylim(1))/20
   plot([xaxis(1) xaxis(max(size(xaxis)))],[0.5*ylim(1)+10*i_plot_all_ygrid 0.5*ylim(1)+10*i_plot_all_ygrid],'k:')
end

% Aufräumen
clear i_plot_all_xgrid i_plot_all_ygrid


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% -- Zeichnen der Balken und Füllflächen -- %%

% Als zweitunterstes Plotelement über dem Hintergrundgitter folgen die verschiedenen Hintergründe
for i_take_each_month=xaxis(1):xaxis(max(size(xaxis)))-1
   for i_print=1:bar_density
      examination_point=i_take_each_month+i_print/bar_density;

      % Jeder Monat wird in "bar_density" gleiche Abstände unterteilt. In jedem dieser Abschnitte werden zuerst die dazugehörigen Werte der
      % Temperatur "combined_tmp" und anschließend des Niederschlags "combined_mm" bestimmt.

      % Zuerst die Ermittlung der Temperatur am Betrachtungspunkt. Dazu wird untersucht, zwischen welchen beiden X-Werten "combined_tmp(1,:)"
      % wir uns aktuell befinden.
      temp_counter=1;
      while (examination_point > combined_tmp(1,temp_counter))
         temp_counter=temp_counter+1;
         if (temp_counter > max(size(combined_tmp)))
            disp(['Abbruch: Zugriff nicht möglich - Implementierung1 ändern']);
            break;
         end
      end

      % Nachdem der nächsthöhere X-Wert gefunden wurde, wird der vorhergehende als Zweitpunkt genommen
      second_value=temp_counter-1;
      if (second_value == 0)
         second_value=xaxis(max(size(xaxis)));
      end

      % Da zwischen den beiden ermittelten Punkten eine lineare Verbindung besteht, kann der aktuelle Temperaturwert "temp_tmp_value" einfach bestimmt werden.
      % Hierzu wird die Steigung zwischen beiden Punkten ermittelt, mit dem aktuellen X-Abstand multipliziert und zum Y-Wert des ersten Punktes addiert.
      temp_tmp_value=combined_tmp(2,second_value)+(combined_tmp(2,temp_counter)-combined_tmp(2,second_value))/(combined_tmp(1,temp_counter)-combined_tmp(1,second_value))*(examination_point-combined_tmp(1,second_value));

      % Analog wird auch der Niederschlag am Betrachtungspunkt ermittelt. Zuerst der nächsthöhere X-Wert...
      temp_counter=1;
      while (examination_point > combined_mm(1,temp_counter))
         temp_counter=temp_counter+1;
         if (temp_counter > max(size(combined_mm)))
            disp(['Abbruch: Zugriff nicht möglich - Implementierung2 ändern']);
            break;
         end
      end

      % ... dann der vorangegangene X-Wert
      second_value=temp_counter-1;
      if (second_value == 0)
         second_value=combined_mm(1,size(combined_mm(2)));
      end

      % Und die tatsächliche Bestimmung erfolgt wieder durch lineare Interpolation
      temp_mm_value=combined_mm(2,second_value)+(combined_mm(2,temp_counter)-combined_mm(2,second_value))/(combined_mm(1,temp_counter)-combined_mm(1,second_value))*(examination_point-combined_mm(1,second_value));


      % Nachdem alle nötigen Werte ermittelt worden sind, wird jetzt untersucht, welcher Wert größer ist.
      if (temp_mm_value >= 2*temp_tmp_value)

         % Falls der doppelte Temperaturwert kleiner ist als der ermittelte Niederschlagswert werden blaue Streifen zwischen beide gezeichnet,
         plot([examination_point examination_point],[max(temp_tmp_value,0) 0.5*temp_mm_value],'-','Color',[0.3 0.4 1],'LineWidth',line_width)

         % Alle Werte über 100mm Niederschlag sollen sich bei einer Änderung der Skala auch sichtbar vom Rest abheben, z.B. durch dickere flächigere Streifen
         if ((temp_mm_value > 100) && (change_precipitation_scale ~= 0))
            plot([examination_point examination_point],[50 0.5*temp_mm_value],'-','Color',[0 0 1],'LineWidth',line_width*2)
         end
      else

         % Falls die doppelte Temperatur größer ist als der dazugehörige Niederschlagswert, so soll der Zwischenraum durch flächige, gelbe Streifen gefüllt werden
         plot([examination_point examination_point],[0.5*temp_mm_value temp_tmp_value],'-','Color',[1 1 0.4],'LineWidth',line_width*2)
      end
   end
end

% Aufräumen
clear examination_point i_take_each_month i_print temp_counter second_value temp_mm_value temp_tmp_value


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% -- Zeichnen der Grundlinie und der eigentlichen Verläufe -- %%

% Zuerst die Grundlinie
plot([xaxis(1) xaxis(max(size(xaxis)))],[0 0],'k-')

% Und darüber dann die beiden eigentlichen Plots
[img_handle,line1,line2]=plotyy(combined_tmp(1,:),combined_tmp(2,:),combined_mm(1,:),combined_mm(2,:));

% Aufräumen
clear combined_tmp combined_mm


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% -- Grafische Feinanpassung der Plots -- %%

% Falls alles verschoben werden soll "half_year_shift" (1), dann soll auch die Bezeichnung entsprechend sein
if (half_year_shift == 1)
   xticklabel=['J';'A';'S';'O';'N';'D';'J';'F';'M';'A';'M';'J'];
else
   xticklabel=['J';'F';'M';'A';'M';'J';'J';'A';'S';'O';'N';'D'];
end

% Anpassen der Liniendicke und -farbe
set(line1,'color',[1 0 0],'LineWidth',line_width)
set(line2,'color',[0 0 1],'LineWidth',line_width)

% Keine Einträge oberhalb der Temperatur "tmp_top", aber aufgrund des Grids müssen die übrigen Felder mit leeren Einträgen gefüttert werden
empty_tmp_entries=[];
for i_fill_the_grid=0:(0.5*ylim(2)-tmp_top)/10-1
   empty_tmp_entries=[empty_tmp_entries {''}];
end

empty_mm_entries=[];
for i_fill_the_grid=0:(-ylim(1)/20)-1
   empty_mm_entries=[empty_mm_entries {''}];
end

% Anpassen der Y-Skala für die Niederschalgswerte
mm_yticklabel=[empty_mm_entries 0:20:ylim(2)];
if ((change_precipitation_scale ~= 0) && (ylim(2) > 100))
   if (change_precipitation_scale == 1)
      new_ylim_top=ceil((ylim(2)-100)/20)*100+100;
      mm_yticklabel=[empty_mm_entries 0:20:80 100:100:new_ylim_top];
   else
      new_ylim_top=ceil((ylim(2)-100)/20)*200+100;
      mm_yticklabel=[empty_mm_entries 0:20:80 100:200:new_ylim_top];
   end
end

% Alle sonstigen Einstellungen zu beiden Verläufen
set(img_handle(1), 'FontSize' , fsize, ...
                   'FontName' , 'Helvetica', ...
                   'Position' , [0.11 0.11 0.775 0.68], ...
                       'XLim' , xlim, ...
                      'XTick' , [1:1:12], ...
                 'XTickLabel' , xticklabel, ...
                       'YLim' , 0.5*ylim, ...
                      'YTick' , [0.5*ylim(1):10:0.5*ylim(2)], ...
                 'YTickLabel' , [0.5*ylim(1):10:tmp_top empty_tmp_entries], ...
                     'YColor' , [1 0 0], ...
                    'TickDir' , 'out', ...
                 'TickLength' , [0.01 0.01], ...
                 'XMinorTick' , 'on', ...
                 'YMinorTick' , 'on')

set(img_handle(2), 'FontSize' , fsize, ...
                   'FontName' , 'Helvetica', ...
                   'Position' , [0.11 0.11 0.775 0.68], ...
                       'XLim' , xlim, ...
                      'XTick' , [1:1:12], ...
                 'XTickLabel' , xticklabel, ...
                       'YLim' , ylim, ...
                      'YTick' , [ylim(1):20:ylim(2)], ...
                 'YTickLabel' , mm_yticklabel, ...
                     'YColor' , [0 0 1], ...
                    'TickDir' , 'out', ...
                 'TickLength' , [0.01 0.01], ...
                 'XMinorTick' , 'on', ...
                 'YMinorTick' , 'on')

% Und am Ende noch die beiden Label der Y-Achsen setzen und formatieren
set(get(img_handle(1),'YLabel'),'String','\circC','Color',[1 0 0],'FontSize',fsize,'FontName','Helvetica','Rotation',0,'Position',[get(tit_handle,'Position').*[0 1 0]+[0.1 3 1]])
set(get(img_handle(2),'YLabel'),'String','mm','Color',[0 0 1],'FontSize',fsize,'FontName','Helvetica','Rotation',0,'Position',[get(tit_handle,'Position').*[0 2 0]+[13.2 16 1]])

% Aufräumen
clear xlim xticklabel ylim mm_yticklabel tmp_top empty_tmp_entries empty_mm_entries new_ylim_top xaxis i_fill_the_grid


%%%%%%%%%%%%%%%%%%%%%
%% -- Aufräumen -- %%

% Einstellungsvariablen
clear custom_plot_height change_precipitation_scale half_year_shift fsize line_width bar_density

% Handles
clear img_handle line1 line2 tit_handle fig_handle

% Datensätze
clear place mm tmp

%% Ende